# Organizer cli
A script that scans throught the current directory and organizes all loose files into neat folders by file extension

## Dependencies
[colorama](https://pypi.org/project/colorama/)

## Installation
```python
pip install organizer-cli
```

## Commands

* safe
* all
* images
* audios
* videos
* office
* vector
* gif
* photoshop
* pdf
* font
* code
* safe
* all


## Usage 
```text
>> Organizer            # Organizes all user friendly files
```
```text
>> Organizer image         # Organizes all image files
```
```text
>> Organizer video         # Organizes all video files
```
```text
>> Organizer audio         # Organizes all audio files
```
```text
>> Organizer office        # Organizes all office files
```
```text
>> Organizer vector        # Organizes all vector files
```
```text
>> Organizer gif           # Organizes all gif files
```
```text
>> Organizer photoshop     # Organizes all photoshop files
```
```text
>> Organizer pdf           # Organizes all pdf files
```
```text
>> Organizer font          # Organizes all font files
```
```text
>> Organizer code          # Organizes all programming files
```
```text
>> Organizer safe          # Organizes all user friendly files
```
```text
>> Organizer all           # Organizes all supported files
```
